.. _example_notebooks:

Examples
=========

Here two examples how *pcrglobwb_utils* can be used. Both can be launched via myBinder in interactive mode (link in notebooks).

.. toctree::
   :maxdepth: 1
   :numbered:
   :glob:

   ./*